@@ -55,17 +55,17 @@ class KNativeConsumer(threading.Thread):
             self.ssl_certfile=os.environ['KAFKA_NET_TLS_CERT']
             self.ssl_keyfile=os.environ['KAFKA_NET_TLS_KEY']
  
-            self.logger.info("Inside if")
+            print("Inside if")
         else:
             self.security_protocol="PLAINTEXT"
             self.ssl_cafile=None
             self.ssl_certfile=None
             self.ssl_keyfile=None
+            self.logger.info("Inside else")
         self.logger.info("KafkaConsumer Instance Creation")
         print("KafkaConsumer Instance Creation")
         try:                
-            self.consumer=KafkaConsumer(
-                          topics=self.topics,
+            self.consumer=KafkaConsumer(                       
                           bootstrap_servers=bootstrap_server,   
                           group_id=group_id,     
                           security_protocol=self.security_protocol,
@@ -107,36 +107,26 @@ class KNativeConsumer(threading.Thread):
         try:
             # (!?) wtf, why we need this to get partitions assigned
             # AssertionError: No partitions are currently assigned if poll() is not called
-            self.consumer.poll()
-            self.consumer.seek_to_beginning()
+            while True:
+                # Response format is {TopicPartiton('topic1', 1): [msg1, msg2]}
+                msg_pack = self.consumer.poll(timeout_ms=500)
+
+                for tp, messages in msg_pack.items():
+                    for message in messages:
+                        # message value and key are raw bytes -- decode if necessary!
+                        # e.g., for unicode: `message.value.decode('utf-8')`
+                        print ("%s:%d:%d: key=%s value=%s" % (tp.topic, tp.partition,
+                                                            message.offset, message.key,
+                                                            message.value))
 
-            # also AssertionError: No partitions are currently assigned if poll() is not called
-            print('partitions of the topic: ',self.consumer.partitions_for_topic(self.topics))
-            self.logger.error('partitions of the topic: ')
-            self.logger.error(self.consumer.partitions_for_topic(self.topics))
-            from kafka import TopicPartition
-            print('before poll() x2: ')
-            # print(self.consumer.position(TopicPartition(self.topics, 0)))
-            print(self.consumer.position(TopicPartition(self.topics, 2)))
-            self.logger.error(self.consumer.position(TopicPartition(self.topics, 2)))
-            # (!?) sometimes the first call to poll() returns nothing and doesnt change the offset
-            messages = self.consumer.poll()
-            sleep(1)
-            messages = self.consumer.poll()
 
-            print('after poll() x2: ')
-            #print(self.consumer.position(TopicPartition(self.topics, 0)))
-            print(self.consumer.position(TopicPartition(self.topics, 2)))
-            self.logger.error(self.consumer.position(TopicPartition(self.topics, 2)))
-            print('messages: ', messages)
-            self.logger.error(messages)
 
 
         except Exception as ex:
-                print("Inexception")
-                print("Exception while getting the message - {}".format(ex))
-                self.logger.error(f'Kafka Exception {ex}')
-                self.logger.error("We have a %s", "major problem. We got an exception!", exc_info=1)
+                print("In msg exception")
+                print("Msg Exception while getting the message - {}".format(ex))
+                self.logger.error(f'Msg Kafka Exception {ex}')
+                self.logger.error("MSg Exception -- We have a %s", "major problem. We got an exception!", exc_info=1)
 
     def getMetric(self):
         tp = self.consumer.assignment()
